@@ -28,6 +28,8 @@ Contact: yuvraaj@gmail.com
 #include <iostream>
 using namespace std;
 
+extern QStringList arrLogFiles;
+
 MainWindow::MainWindow (QWidget *parent)
 : QDeclarativeView (parent)
 , gvApi (true, this)
@@ -36,6 +38,7 @@ MainWindow::MainWindow (QWidget *parent)
 , oContacts (this)
 , oInbox (gvApi, this)
 , vmailPlayer (NULL)
+, nwMgr (NULL)
 , statusTimer (this)
 #ifdef Q_WS_MAEMO_5
 , infoBox (this)
@@ -131,7 +134,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.3.854");
+    setStatus("Using qgvdial version 0.3.863");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -567,38 +570,6 @@ MainWindow::initQML ()
                    this, SLOT   (onSigCloseVmail ()));
     Q_ASSERT(bOk);
     if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigUserChanged (const QString &)),
-                   this, SLOT   (onUserTextChanged (const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigPassChanged (const QString &)),
-                   this, SLOT   (onPassTextChanged (const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigLogin ()),
-                   this, SLOT   (doLogin ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigLogout ()),
-                   this, SLOT   (doLogout ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigRefresh ()),
-                   this, SLOT   (onRefresh ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigRefreshAll ()),
-                   this, SLOT   (onRefreshAll ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigRefreshInbox ()),
-                   this, SLOT   (onSigRefreshInbox ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigRefreshContacts ()),
-                   this, SLOT   (onSigRefreshContacts ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
     bOk = connect (gObj, SIGNAL (sigHide ()),
                    this, SLOT   (onSigHide ()));
     Q_ASSERT(bOk);
@@ -607,38 +578,6 @@ MainWindow::initQML ()
                    this, SLOT   (on_actionE_xit_triggered ()));
     Q_ASSERT(bOk);
     if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigLinkActivated (const QString &)),
-                   this, SLOT   (onLinkActivated (const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (
-        gObj, SIGNAL (sigProxyChanges(bool, bool, const QString &, int,
-                                      bool, const QString &, const QString &)),
-        this, SLOT (onSigProxyChanges(bool, bool, const QString &, int,
-                                      bool, const QString &, const QString &)));
-    bOk = connect (gObj, SIGNAL (sigProxyRefresh()),
-                   this, SLOT (onSigProxyRefresh()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (
-        gObj, SIGNAL (sigMosquittoChanges(bool, const QString &, int,
-                                          const QString &)),
-        this, SLOT   (onSigMosquittoChanges(bool, const QString &, int,
-                                            const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigMosquittoRefresh()),
-                   this, SLOT   (refreshMqSettings()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (
-        gObj, SIGNAL(sigPinSettingChanges  (bool, const QString &)),
-        this, SLOT  (onSigPinSettingChanges(bool, const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL(sigPinRefresh()),
-                   this, SLOT  (refreshPinSettings()));
-    Q_ASSERT(bOk);
     if (!bOk) { exit(1); }
     bOk = connect (gObj, SIGNAL (sigMsgBoxDone(bool)),
                    this, SLOT (onSigMsgBoxDone(bool)));
@@ -650,6 +589,11 @@ MainWindow::initQML ()
     Q_ASSERT(bOk);
     if (!bOk) { exit(1); }
 
+    // Now do the settings page
+    if (!connectSettingsSignals ()) {
+        exit (1);
+    }
+
 #if MOBILE_OS
     bOk = connect(qApp->desktop(), SIGNAL(resized(int)),
                   this           , SLOT(onDesktopResized()));
@@ -669,6 +613,97 @@ MainWindow::initQML ()
 
 }//MainWindow::initQML
 
+bool
+MainWindow::connectSettingsSignals()
+{
+    bool rv = false;
+    QObject *obj = getQMLObject ("SettingsPage");
+
+    do { // Begin cleanup block (not a loop)
+        if (obj == NULL) {
+            Q_WARN("Could not find SettingsPage");
+            break;
+        }
+        rv = connect (obj , SIGNAL (sigUserChanged (const QString &)),
+                      this, SLOT   (onUserTextChanged (const QString &)));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigPassChanged (const QString &)),
+                      this, SLOT   (onPassTextChanged (const QString &)));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigLogin ()),
+                      this, SLOT   (doLogin ()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigLogout ()),
+                      this, SLOT   (doLogout ()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigLinkActivated (const QString &)),
+                      this, SLOT   (onLinkActivated (const QString &)));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj,
+                      SIGNAL (sigProxyChanges(bool, bool, const QString &, int,
+                                              bool, const QString &,
+                                              const QString &)),
+                      this,
+                      SLOT (onSigProxyChanges(bool, bool, const QString &, int,
+                                              bool, const QString &,
+                                              const QString &)));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigProxyRefresh()),
+                      this, SLOT (onSigProxyRefresh()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj,
+                      SIGNAL (sigMosquittoChanges(bool, const QString &, int,
+                                                  const QString &)),
+                      this,
+                      SLOT   (onSigMosquittoChanges(bool, const QString &, int,
+                                                    const QString &)));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigMosquittoRefresh()),
+                      this, SLOT   (refreshMqSettings()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (
+                    obj , SIGNAL(sigPinSettingChanges  (bool, const QString &)),
+                    this, SLOT (onSigPinSettingChanges(bool, const QString &)));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL(sigPinRefresh()),
+                      this, SLOT  (refreshPinSettings()));
+        Q_ASSERT(rv);
+        rv = connect (obj , SIGNAL (sigRefresh ()),
+                      this, SLOT   (onRefresh ()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigRefreshAll ()),
+                      this, SLOT   (onRefreshAll ()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigRefreshInbox ()),
+                      this, SLOT   (onSigRefreshInbox ()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+        rv = connect (obj , SIGNAL (sigRefreshContacts ()),
+                      this, SLOT   (onSigRefreshContacts ()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+
+        rv = connect (obj , SIGNAL (sigSendLogs ()),
+                      this, SLOT   (onSigSendLogs ()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+    } while (0); // End cleanup block (not a loop)
+
+    return (rv);
+}//MainWindow::connectSettingsSignals
+
 /** Invoked to begin the login process.
  * We already have the username and password, so just start the login to the GV
  * website. The async completion routine is loginCompleted.
@@ -2131,3 +2166,157 @@ MainWindow::onSigGvApiProgress(double percent)
     QString msg = QString("Progress : %1%").arg (percent);
     setStatus (msg);
 }//MainWindow::onSigGvApiProgress
+
+bool
+MainWindow::ensureNwMgr()
+{
+    if (nwMgr) {
+        return true;
+    }
+
+    nwMgr = new QNetworkAccessManager(this);
+
+    return (nwMgr != NULL);
+}//MainWindow::ensureNwMgr
+
+void
+MainWindow::onSigSendLogs()
+{
+    if (!ensureNwMgr ()) {
+        Q_WARN("Failed to ensure NW Mgr");
+        return;
+    }
+
+    QUrl url(LOGS_SERVER "/qgvdial/getLogLocation.py");
+    QNetworkRequest req(url);
+    QNetworkReply *reply = nwMgr->get (req);
+    if (!reply) {
+        return;
+    }
+
+    NwReqTracker *tracker = new NwReqTracker(reply, NULL, NW_REPLY_TIMEOUT,
+                                             true, this);
+    connect(tracker, SIGNAL(sigDone(bool,QByteArray,QNetworkReply*,void*)),
+            this, SLOT(onGetLogLocation(bool,QByteArray,QNetworkReply*,void*)));
+}//MainWindow::onSigSendLogs
+
+void
+MainWindow::onGetLogLocation(bool success, const QByteArray &response,
+                             QNetworkReply *reply, void * /*ctx*/)
+{
+    do { // Begin cleanup block (not a loop)
+        if (!success) {
+            QString strR = reply->readAll ();
+            Q_WARN("Failed to get location to post logs") << strR;
+            break;
+        }
+
+        if (!ensureNwMgr ()) {
+            Q_WARN("Failed to ensure NW Mgr");
+            break;
+        }
+
+        AsyncTaskToken *token = new AsyncTaskToken(this);
+        if (!token) {
+            Q_WARN("Failed to create async token");
+            break;
+        }
+
+        QDateTime dtNow = QDateTime::currentDateTime().toUTC();
+        token->inParams["date"] = dtNow;
+
+        QDomDocument doc("qgvdial Logs");
+        QDomElement root = doc.createElement("Logs");
+        doc.appendChild(root);
+
+
+        QDomElement paramsTag = doc.createElement("Params");
+        root.appendChild(paramsTag);
+
+        QDomElement dateTag = doc.createElement("Date");
+        paramsTag.appendChild(dateTag);
+
+        QDomText dateTagText = doc.createTextNode(dtNow.toString (Qt::ISODate));
+        dateTag.appendChild(dateTagText);
+
+        QDomElement appVerTag = doc.createElement("Version");
+        paramsTag.appendChild(appVerTag);
+
+        QDomText appVerText = doc.createTextNode("0.3.863");
+        appVerTag.appendChild(appVerText);
+
+        QDomElement osVerTag = doc.createElement("OsVer");
+        paramsTag.appendChild(osVerTag);
+
+        OsDependent &osd = Singletons::getRef().getOSD ();
+        QDomText osVerText = doc.createTextNode(osd.getOSDetails());
+        osVerTag.appendChild(osVerText);
+
+        for (int i = arrLogFiles.count(); i > 0; i--) {
+            QFile fLog(arrLogFiles[i-1]);
+            if (!fLog.open (QIODevice::ReadOnly)) {
+                continue;
+            }
+
+            QDomElement oneLogFile = doc.createElement(arrLogFiles[i-1]);
+            root.appendChild(oneLogFile);
+
+            QDomText t = doc.createTextNode(fLog.readAll ());
+            oneLogFile.appendChild(t);
+        }
+
+        QString postLocation = response;
+        QUrl url(postLocation);
+        QNetworkRequest req(url);
+        req.setHeader (QNetworkRequest::ContentTypeHeader, POST_TEXT);
+
+        reply = nwMgr->post (req, doc.toString().toAscii ());
+        if (!reply) {
+            break;
+        }
+
+        NwReqTracker *tracker = new NwReqTracker(reply, token, NW_REPLY_TIMEOUT,
+                                                 true, this);
+        connect(tracker, SIGNAL(sigDone(bool,QByteArray,QNetworkReply*,void*)),
+                this, SLOT(onLogPosted(bool,QByteArray,QNetworkReply*,void*)));
+    } while (0); // End cleanup block (not a loop)
+}//MainWindow::onGetLogLocation
+
+void
+MainWindow::onLogPosted(bool success, const QByteArray &response,
+                        QNetworkReply *reply, void *ctx)
+{
+    AsyncTaskToken *token = (AsyncTaskToken *) ctx;
+    do { // Begin cleanup block (not a loop)
+        if (!success) {
+            QString strR = reply->readAll ();
+            Q_WARN("Failed to post the logs") << strR;
+            break;
+        }
+
+        QString strReply = response;
+
+        QUrl url("mailto:yuvraaj@gmail.com");
+        url.addQueryItem ("subject", "Logs");
+
+        OsDependent &osd = Singletons::getRef().getOSD ();
+        QDateTime dt = token->inParams["date"].toDateTime();
+        QString body = QString("Logs captured at %1 \n")
+                                .arg (dt.toUTC ().toString (Qt::ISODate));
+        body += "qgvdial version = 0.3.863 \n";
+        body += QString("OS: %1 \n").arg(osd.getOSDetails());
+        body += QString("Logs are in %1 \n").arg(strReply);
+        url.addQueryItem ("body", body);
+
+        Q_DEBUG(url.toString ());
+
+        if (!QDesktopServices::openUrl (url)) {
+            Q_WARN("Failed to send email about logs");
+            setStatus ("Failed to send email");
+        }
+    } while (0); // End cleanup block (not a loop)
+
+    if (token) {
+        delete token;
+    }
+}//MainWindow::onLogPosted
